@@ -5,18 +5,23 @@
 #' @examples \dontrun{
 #' plosabstract(terms = 'drosophila', fields='abstract', limit=10)
 #' plosabstract(terms = 'drosophila', fields='id,author', limit = 5)
+#' plosabstract(terms = 'drosophila', fields='author', limit = 5)
 #' plosabstract(terms = 'drosophila', fields='id,author,title', limit = 5)
 #' plosabstract(terms = 'drosophila', fields='id,author,title', limit = 5, 
 #'  callopts=list(verbose=TRUE))
+#' 
+#' # Highlighting
+#' plosabstract(terms='drosophila', fields='abstract', limit = 2, highlighting=TRUE)
 #' }
 #' @export
 
-plosabstract <- function(terms = NA, fields = 'id', toquery = NA, start = 0, 
-  limit = NA, returndf = TRUE, sleep = 6, curl = getCurlHandle(),
+plosabstract <- function(terms = NA, fields = 'id', toquery = NA, sort = NA, 
+  highlighting = FALSE, start = 0, limit = NA, returndf = TRUE, sleep = 6,
   key = getOption("PlosApiKey", stop("need an API key for PLoS Journals")), 
-  callopts=list())
+  curl = getCurlHandle(), callopts=list())
 {
   searchplos(terms=paste('abstract:', '"', terms, '"', sep=""), fields=fields, 
-             toquery=toquery, start=start, limit=limit, returndf=returndf, 
-             sleep=sleep, curl=curl, key=key, callopts=callopts)
+             toquery=toquery, sort=sort, highlighting=highlighting, start=start, 
+             limit=limit, returndf=returndf, sleep=sleep, curl=curl, key=key, 
+             callopts=callopts)
 }
\ No newline at end of file
