@@ -6,15 +6,19 @@
 #' plostitle(terms='drosophila', fields='title', limit=99)
 #' plostitle(terms='drosophila', fields='title,journal', limit=10)
 #' plostitle(terms='drosophila',  limit = 5)
+#' 
+#' # Highlighting
+#' plostitle(terms='drosophila',  limit = 5, highlighting=TRUE)
 #' }
 #' @export
 
-plostitle <- function(terms = NA, fields = 'id', toquery = NA, start = 0, 
-  limit = NA, returndf = TRUE, sleep = 6, curl = getCurlHandle(),
+plostitle <- function(terms = NA, fields = 'id', toquery = NA, sort = NA, 
+  highlighting = FALSE, start = 0, limit = NA, returndf = TRUE, sleep = 6, 
   key = getOption("PlosApiKey", stop("need an API key for PLoS Journals")), 
-  callopts=list())
+  curl = getCurlHandle(), callopts=list())
 {
   searchplos(terms=paste('title:', '"', terms, '"', sep=""), fields=fields, 
-             toquery=toquery, start=start, limit=limit, returndf=returndf, 
-             sleep=sleep, curl=curl, key=key, callopts=callopts)
+             toquery=toquery, sort=sort, highlighting=highlighting, start=start, 
+             limit=limit, returndf=returndf, sleep=sleep, curl=curl, key=key, 
+             callopts=callopts)
 }
\ No newline at end of file
